"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionsEditorApplier = void 0;
const plugin_1 = require("@stryker-mutator/api/plugin");
const typed_inject_1 = require("typed-inject");
const di_1 = require("../di");
const createConfig_1 = require("./createConfig");
/**
 * Class that applies all config editor plugins
 */
class OptionsEditorApplier {
    constructor(pluginResolver, configEditorPluginCreator, optionsEditorPluginCreator) {
        this.pluginResolver = pluginResolver;
        this.configEditorPluginCreator = configEditorPluginCreator;
        this.optionsEditorPluginCreator = optionsEditorPluginCreator;
    }
    edit(options) {
        this.pluginResolver.resolveAll(plugin_1.PluginKind.OptionsEditor).map((plugin) => {
            const optionsEditor = this.optionsEditorPluginCreator.create(plugin.name);
            optionsEditor.edit(options);
        });
        // Deprecated "config editors"
        const configEditors = this.pluginResolver.resolveAll(plugin_1.PluginKind.ConfigEditor);
        if (configEditors.length) {
            const config = createConfig_1.createConfig(options);
            configEditors.forEach((plugin) => {
                const configEditor = this.configEditorPluginCreator.create(plugin.name);
                configEditor.edit(config);
            });
        }
    }
}
exports.OptionsEditorApplier = OptionsEditorApplier;
OptionsEditorApplier.inject = typed_inject_1.tokens(plugin_1.commonTokens.pluginResolver, di_1.coreTokens.pluginCreatorConfigEditor, di_1.coreTokens.pluginCreatorOptionsEditor);
//# sourceMappingURL=OptionsEditorApplier.js.map