import { Logger } from '@stryker-mutator/api/logging';
import NpmClient from './NpmClient';
import Preset from './presets/Preset';
import StrykerConfigWriter from './StrykerConfigWriter';
import { StrykerInquirer } from './StrykerInquirer';
import GitignoreWriter from './GitignoreWriter';
export default class StrykerInitializer {
    private readonly log;
    private readonly out;
    private readonly client;
    private readonly strykerPresets;
    private readonly configWriter;
    private readonly gitignoreWriter;
    private readonly inquirer;
    static inject: ["logger", "out", "npmClient", "strykerPresets", "configWriter", "gitignoreWriter", "inquirer"];
    constructor(log: Logger, out: typeof console.log, client: NpmClient, strykerPresets: Preset[], configWriter: StrykerConfigWriter, gitignoreWriter: GitignoreWriter, inquirer: StrykerInquirer);
    /**
     * Runs the initializer will prompt the user for questions about his setup. After that, install plugins and configure Stryker.
     * @function
     */
    initialize(): Promise<void>;
    /**
     * The typed rest client works only with the specific HTTP_PROXY and HTTPS_PROXY env settings.
     * Let's make sure they are available.
     */
    private patchProxies;
    private selectPreset;
    private initiatePreset;
    private initiateCustom;
    private selectTestRunner;
    private selectReporters;
    private selectTestFramework;
    private selectMutator;
    private selectTranspilers;
    private selectPackageManager;
    private selectJsonConfigType;
    private getSelectedNpmDependencies;
    /**
     * Install the npm packages
     * @function
     */
    private installNpmDependencies;
    private fetchAdditionalConfig;
}
//# sourceMappingURL=StrykerInitializer.d.ts.map