"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializerTokens = exports.initializerFactory = void 0;
const plugin_1 = require("@stryker-mutator/api/plugin");
const log4js_1 = require("log4js");
const typed_inject_1 = require("typed-inject");
const typed_rest_client_1 = require("typed-rest-client");
const factoryMethods_1 = require("../di/factoryMethods");
const initializerTokens = require("./initializerTokens");
exports.initializerTokens = initializerTokens;
const NpmClient_1 = require("./NpmClient");
const StrykerConfigWriter_1 = require("./StrykerConfigWriter");
const StrykerInitializer_1 = require("./StrykerInitializer");
const StrykerInquirer_1 = require("./StrykerInquirer");
const StrykerPresets_1 = require("./StrykerPresets");
const GitignoreWriter_1 = require("./GitignoreWriter");
const BASE_NPM_SEARCH = 'https://api.npms.io';
const BASE_NPM_PACKAGE = 'https://www.unpkg.com';
function initializerFactory() {
    return typed_inject_1.rootInjector
        .provideValue(plugin_1.commonTokens.getLogger, log4js_1.getLogger)
        .provideFactory(plugin_1.commonTokens.logger, factoryMethods_1.loggerFactory)
        .provideValue(initializerTokens.out, console.log)
        .provideValue(initializerTokens.strykerPresets, StrykerPresets_1.default)
        .provideValue(initializerTokens.restClientNpmSearch, new typed_rest_client_1.RestClient('npmSearch', BASE_NPM_SEARCH))
        .provideValue(initializerTokens.restClientNpm, new typed_rest_client_1.RestClient('npm', BASE_NPM_PACKAGE))
        .provideClass(initializerTokens.npmClient, NpmClient_1.default)
        .provideClass(initializerTokens.configWriter, StrykerConfigWriter_1.default)
        .provideClass(initializerTokens.gitignoreWriter, GitignoreWriter_1.default)
        .provideClass(initializerTokens.inquirer, StrykerInquirer_1.StrykerInquirer)
        .injectClass(StrykerInitializer_1.default);
}
exports.initializerFactory = initializerFactory;
//# sourceMappingURL=index.js.map