"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configure = exports.MultiAppender = void 0;
class MultiAppender {
    constructor(appenders) {
        this.appenders = appenders;
    }
    append(loggingEvent) {
        this.appenders.forEach((appender) => appender(loggingEvent));
    }
}
exports.MultiAppender = MultiAppender;
/**
 * This method is expected by log4js to have this _exact_ name
 * and signature.
 * @see https://log4js-node.github.io/log4js-node/writing-appenders.html
 * @param config The appender configuration delivered by log4js
 * @param _ The layouts provided by log4js
 * @param findAppender A method to locate other appenders
 */
function configure(config, _, findAppender) {
    const multiAppender = new MultiAppender(config.appenders.map((name) => findAppender(name)));
    return multiAppender.append.bind(multiAppender);
}
exports.configure = configure;
//# sourceMappingURL=MultiAppender.js.map