import CircleProvider from './CircleProvider';
import TravisProvider from './TravisProvider';
import GithubActionsCIProvider from './GithubActionsProvider';
/**
 * Represents an object that can provide information about a CI/CD provider.
 */
export interface CIProvider {
    /**
     * Determine the repository slug, including the git provider. I.E: github.com/stryker-mutator/stryker or bitbucket.org/org/name.
     */
    determineProject(): string | undefined;
    /**
     * Determine the current version. I.e. branch name, git sha, or tag name
     */
    determineVersion(): string | undefined;
}
/**
 * Return an appropriate instance of CiProvider.
 * @returns An instance of CiProvider, or `null` if it appears Stryker is not running in a CI/CD environment.
 */
export declare function determineCIProvider(): CircleProvider | TravisProvider | GithubActionsCIProvider | null;
//# sourceMappingURL=Provider.d.ts.map