"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determineCIProvider = void 0;
const objectUtils_1 = require("../../utils/objectUtils");
const CircleProvider_1 = require("./CircleProvider");
const TravisProvider_1 = require("./TravisProvider");
const GithubActionsProvider_1 = require("./GithubActionsProvider");
/**
 * Return an appropriate instance of CiProvider.
 * @returns An instance of CiProvider, or `null` if it appears Stryker is not running in a CI/CD environment.
 */
function determineCIProvider() {
    // By far the coolest env. variable from all those listed at
    // https://docs.travis-ci.com/user/environment-variables/#Default-Environment-Variables
    if (objectUtils_1.getEnvironmentVariable('HAS_JOSH_K_SEAL_OF_APPROVAL')) {
        return new TravisProvider_1.default();
    }
    else if (objectUtils_1.getEnvironmentVariable('CIRCLECI')) {
        return new CircleProvider_1.default();
    }
    else if (objectUtils_1.getEnvironmentVariable('GITHUB_ACTION')) {
        return new GithubActionsProvider_1.default();
    }
    // TODO: Add vsts and gitlab CI
    return null;
}
exports.determineCIProvider = determineCIProvider;
//# sourceMappingURL=Provider.js.map