"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_runner_1 = require("@stryker-mutator/api/test_runner");
const log4js_1 = require("log4js");
const objectUtils_1 = require("../utils/objectUtils");
const TestRunnerDecorator_1 = require("./TestRunnerDecorator");
/**
 * Wraps a test runner and implements the timeout functionality.
 */
class TimeoutDecorator extends TestRunnerDecorator_1.default {
    constructor() {
        super(...arguments);
        this.log = log4js_1.getLogger(TimeoutDecorator.name);
    }
    async run(options) {
        this.log.debug('Starting timeout timer (%s ms) for a test run', options.timeout);
        const result = await objectUtils_1.timeout(super.run(options), options.timeout);
        if (result === objectUtils_1.TimeoutExpired) {
            return this.handleTimeout();
        }
        else {
            return result;
        }
    }
    handleTimeout() {
        this.log.debug('Timeout expired, restarting the process and reporting timeout');
        return this.dispose()
            .then(() => this.createInnerRunner())
            .then(() => this.init())
            .then(() => ({ status: test_runner_1.RunStatus.Timeout, tests: [] }));
    }
}
exports.default = TimeoutDecorator;
//# sourceMappingURL=TimeoutDecorator.js.map